/*
 * XdccDownloader - ChannelLeft.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.irc.event;

import net.pterodactylus.irc.Connection;
import net.pterodactylus.irc.Source;

import com.google.common.base.Optional;

/**
 * Event that notifies a listener that a client has left a channel.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class ChannelLeft extends AbstractChannelEvent {

	/** The parting client. */
	private final Source client;

	/** The message given by the client. */
	private final Optional<String> message;

	/**
	 * Creates a new channel joined event.
	 *
	 * @param connection
	 * 		The connection that joined the channel
	 * @param channel
	 * 		The channel being left
	 * @param message
	 * 		The message given by the client
	 */
	public ChannelLeft(Connection connection, String channel, Source client, Optional<String> message) {
		super(connection, channel);
		this.client = client;
		this.message = message;
	}

	//
	// ACCESSORS
	//

	/**
	 * Returns the client that joined the channel.
	 *
	 * @return The client that joined the channel
	 */
	public Source client() {
		return client;
	}

	/**
	 * Returns the message given by the client.
	 *
	 * @return The message given by the client
	 */
	public Optional<String> message() {
		return message;
	}

}
