/*
 * XdccDownloader - Server.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.xdcc.data;

import java.util.Collection;

import com.google.common.collect.ImmutableSet;

/**
 * Defines a server in a {@link Network}.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class Server {

	/** The network this server belongs to. */
	private final Network network;

	/** The hostname of this server. */
	private final String hostname;

	/** The unencrypted port numbers. */
	private final Collection<Integer> unencryptedPorts;

	/** The encrypted port numbers. */
	private final Collection<Integer> encryptedPorts;

	/**
	 * Creates a new server.
	 *
	 * @param network
	 * 		The network this server belongs to
	 * @param hostname
	 * 		The hostname of the server
	 * @param unencryptedPorts
	 * 		The unencrypted port numbers
	 * @param encryptedPorts
	 * 		The encrypted port numbers
	 */
	public Server(Network network, String hostname, Collection<Integer> unencryptedPorts, Collection<Integer> encryptedPorts) {
		this.network = network;
		this.hostname = hostname;
		this.unencryptedPorts = ImmutableSet.copyOf(unencryptedPorts);
		this.encryptedPorts = ImmutableSet.copyOf(encryptedPorts);
	}

	//
	// ACCESSORS
	//

	/**
	 * Returns the network this server belongs to.
	 *
	 * @return The network this server belongs to
	 */
	public Network network() {
		return network;
	}

	/**
	 * Returns the hostname of this server.
	 *
	 * @return The hostname of this server
	 */
	public String hostname() {
		return hostname;
	}

	/**
	 * Returns the unencrypted port numbers.
	 *
	 * @return The unencrypted port numbers
	 */
	public Collection<Integer> unencryptedPorts() {
		return unencryptedPorts;
	}

	/**
	 * Returns the encrypted port numbers.
	 *
	 * @return The encrypted port numbers
	 */
	public Collection<Integer> encryptedPorts() {
		return encryptedPorts;
	}

}
