/*
 * XdccDownloader - DuplicateLineSuppressingWriterTest.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.xdcc.util.io;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.is;

import java.io.IOException;
import java.io.StringWriter;

import org.junit.Test;

/**
 * Unit test for {@link DuplicateLineSuppressingWriter}.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class DuplicateLineSuppressingWriterTest {

	private final StringWriter stringWriter = new StringWriter();
	private final DuplicateLineSuppressingWriter duplicateLineSuppressingWriter = new DuplicateLineSuppressingWriter(stringWriter);

	@Test
	public void theFirstLineIsWrittenImmediately() throws IOException {
		duplicateLineSuppressingWriter.write("First Line.\n");
		assertThat(stringWriter.toString(), is("First Line.\n"));
	}

	@Test
	public void twoDifferentLinesAreWrittenOut() throws IOException {
		duplicateLineSuppressingWriter.write("First Line.\n");
		duplicateLineSuppressingWriter.write("Second Line.\n");
		assertThat(stringWriter.toString(), is("First Line.\nSecond Line.\n"));
	}

	@Test
	public void twoEqualLinesAreOnlyWrittenOnce() throws IOException {
		duplicateLineSuppressingWriter.write("First Line.\n");
		duplicateLineSuppressingWriter.write("First Line.\n");
		assertThat(stringWriter.toString(), is("First Line.\n"));
	}

	@Test
	public void multipleLinesAreSuppressed() throws IOException {
		duplicateLineSuppressingWriter.write("First Line.\n");
		duplicateLineSuppressingWriter.write("Second Line.\n");
		duplicateLineSuppressingWriter.write("Second Line.\n");
		duplicateLineSuppressingWriter.write("Second Line.\n");
		duplicateLineSuppressingWriter.write("First Line.\n");
		duplicateLineSuppressingWriter.write("First Line.\n");
		assertThat(stringWriter.toString(), is("First Line.\nSecond Line.\nFirst Line.\n"));
	}

	@Test
	public void resettingTheWriterAllowsADuplicateLine() throws IOException {
		duplicateLineSuppressingWriter.write("First Line.\n");
		duplicateLineSuppressingWriter.write("Second Line.\n");
		duplicateLineSuppressingWriter.reset();
		duplicateLineSuppressingWriter.write("Second Line.\n");
		assertThat(stringWriter.toString(), is("First Line.\nSecond Line.\nSecond Line.\n"));
	}

}
